/*
 * $Id: dnssec.c 434 2010-06-10 20:25:05Z jakob $
 *
 * Copyright (C) 2010 Internet Corporation for Assigned Names 
 *                    and Numbers ("ICANN")
 *
 * Permission to use, copy, modify, and distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND ICANN DISCLAIMS ALL WARRANTIES WITH
 * REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
 * AND FITNESS.  IN NO EVENT SHALL ICANN BE LIABLE FOR ANY SPECIAL, DIRECT,
 * INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
 * LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE
 * OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THIS SOFTWARE.
 *
 */

#include <string.h>

#include "dnssec.h"

/* Calculate DNSSEC keytag */
uint16_t dnssec_keytag (const uint8_t *key, size_t klen)
{
  uint32_t acm;
  int i;

  for(acm=0,i=0;i<(int)klen;++i) acm += (i&1)?key[i]:(key[i]<< 8);
  acm += (acm>>16)&0xFFFF;
  return acm&0xFFFF;
}

/* Put a canonicalized representation of ASCII
   domain name in wire format, returning len */
size_t dnssec_dn2wire(const char *dn, uint8_t *wire)
{
  size_t n;
  uint8_t *p,*q,*q0;

  if(strcmp(dn,".") == 0) {
    wire[0] = '\0';
    return 1;
  }

  q0 = wire;
  q = q0 + 1;
  n = 0;

  for(p=(uint8_t *)dn;*p;p++) {
    if(*p == '.') {
      *q0 = (uint8_t)n;
      q0 += (n+1);
      q = q0 + 1;
      n = 0;
      continue;
    }
    *q++ = *p;
    n++;
  }

  *q0 = (uint8_t)n;
  q0 += (n+1);
  n = (int)(q0 - wire);

  return n;
}
